@@ -1,59 +1,12 @@
 package Google::AJAX::Library;
+BEGIN {
+  $Google::AJAX::Library::VERSION = '0.021';
+}
+# ABSTRACT: Access the Google AJAX Libaries API in Perl
 
 use warnings;
 use strict;
 
-=head1 NAME
-
-Google::AJAX::Library - Access the Google AJAX Libaries API in Perl
-
-=head1 VERSION
-
-Version 0.02
-
-=cut
-
-our $VERSION = '0.02';
-
-=head1 SYNOPSIS
-
-    use Google::AJAX::Library;
-
-    my $library = Google::AJAX::Library->jquery;
-
-    $library->uri
-    # http://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js
-
-    $library->html
-    # <script src="http://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js" type="text/javascript"></script>
-
-You can also fetch or write-out the library content:
-
-    my $library = Google::AJAX::Library->new(name => "mootools", version => "1.8.1");
-
-    my $content = $library->fetch;
-
-    # Into a scalar:
-    my $content;
-    $library->fetch(\$content)
-
-    # To a filehandle:
-    $library->write(\*STDOUT)
-
-    # To a file:
-    $library->write("/path/to/library.js")
-
-    # Check if a library exists at http://ajax.googleapis.com
-    # This will just do a HEAD request
-    $library->exists
-
-=head1 DESCRIPTION
-
-Google::AJAX::Library is a module for accessing the Google AJAX Libaries API via Perl
-
-You can find out more about the API here: http://code.google.com/apis/ajaxlibs/
-
-=cut
 
 use Moose;
 use Google::AJAX::Library::Carp;
@@ -72,35 +25,21 @@ use constant LATEST_VERSION => {qw/
     dojo 1
 /};
 
+$Google::AJAX::Library::VERSION ||= 0;
+
 has uri => qw/is ro/;
 has version => qw/is ro/;
 has file => qw/is ro/;
 has name => qw/is ro/;
 has ua => qw/is ro required 1 lazy 1 isa LWP::UserAgent/, default => sub {
     my $ua = LWP::UserAgent->new;
-    $ua->agent("Google::AJAX::Library/$VERSION (" . $ua->agent . ")");
+    
+    $ua->agent("Google::AJAX::Library/$Google::AJAX::Library::VERSION (" . $ua->agent . ")");
     return $ua;
 };
 
 sub _christen;
 
-=head1 METHODS
-
-=head2 Google::AJAX::Library->jquery([ <version>, <extra> ])
-
-=head2 Google::AJAX::Library->jQuery([ <version>, <extra> ])
-
-Returns a jQuery library object of the given version
-
-If no version is given or the given version is 0, then the latest version (1) will be used
-
-You can pass through "uncompressed = 1" to get the non-compacted .js
-
-For example:
-
-    my $library = Google::AJAX::Library->jQuery(1.2, uncompressed => 1)
-
-=cut
 
 sub jquery {
     return _christen jquery => @_;
@@ -110,45 +49,16 @@ sub jQuery {
     return _christen jquery => @_;
 }
 
-=head2 Google::AJAX::Library->prototype([ <version> ])
-
-Returns a prototype library object of the given version
-
-If no version is given or the given version is 0, then the latest version (1) will be used
-
-A compressed .js is not offered at this time
-
-=cut
 
 sub prototype {
     return _christen prototype => @_;
 }
 
-=head2 Google::AJAX::Library->scriptaculous([ <version> ])
-
-Returns a script.aculo.us library object of the given version
-
-If no version is given or the given version is 0, then the latest version (1) will be used
-
-A compressed .js is not offered at this time
-
-=cut
 
 sub scriptaculous {
     return _christen scriptaculous => @_;
 }
 
-=head2 Google::AJAX::Library->mootools([ <version>, <extra> ])
-
-=head2 Google::AJAX::Library->MooTools([ <version>, <extra> ])
-
-Returns a MooTools library object of the given version
-
-If no version is given or the given version is 0, then the latest version (1) will be used
-
-You can pass through "uncompressed = 1" to get the non-compacted .js
-
-=cut
 
 sub mootools {
     return _christen mootools => @_;
@@ -158,41 +68,11 @@ sub MooTools {
     return _christen mootools => @_;
 }
 
-=head2 Google::AJAX::Library->dojo([ <version>, <extra> ])
-
-Returns a Dojo library object of the given version
-
-If no version is given or the given version is 0, then the latest version (1) will be used
-
-You can pass through "uncompressed = 1" to get the non-compacted .js
-
-=cut
 
 sub dojo {
     return _christen dojo => @_;
 }
 
-=head2 $library->uri
-
-Returns the L<URI> for $library
-
-=head2 $library->version
-
-Returns the version of $library
-
-=head2 $library->name
-
-Returns the name of $library (e.g. jquery, scriptaculous, etc.)
-
-=head2 $library->file
-
-Returns the filename of $library (e.g. jquery.min.js, dojo/dojo.xd.js, etc.)
-
-=head2 $library->html
-
-Returns a properly formatted HTML <script></script> entry for $library
-
-=cut
 
 sub html {
     my $self = shift;
@@ -267,26 +147,12 @@ sub _name_file {
     return ($name, $file);
 }
 
-=head2 $library->exists
-
-Returns 1 if the $library (at the URI, including the specified version) exists at http://ajax.googleapis.com/
-
-Returns 0 otherwise
-
-This method uses a HEAD request to do the checking
-
-=cut
 
 sub exists {
     my $self = shift;
     return $self->ua->head($self->uri)->is_success ? 1 : 0;
 }
 
-=head2 $library->request
-
-Returns the L<HTTP::Response> of the GET request for $library
-
-=cut
 
 sub request {
     my $self = shift;
@@ -294,17 +160,6 @@ sub request {
     return $self->ua->get($self->uri);
 }
 
-=head2 $library->fetch([ <to> ])
-
-Attempts to GET $library
-
-Returns the L<HTTP::Response> decoded content If <to> is not given
-
-If <to> is a SCALAR reference then the content will be put into <to>
-
-This method is synonymous/interchangeable with C<write>
-
-=cut
 
 sub fetch {
     my $self = shift;
@@ -325,19 +180,6 @@ sub fetch {
     return 1;
 }
 
-=head2 $library->write( <to> )
-
-Attempts to GET $library
-
-If <to> is a GLOB reference then the content will be printed to <to>
-
-If <to> is a filename (or Path::Class::File object) then the content will be printed to the filename specified
-
-This method will croak if $library couldn't be gotten from Google (e.g. 404)
-
-This method is synonymous/interchangeable with C<fetch>
-
-=cut
 
 sub write {
     my $self = shift;
@@ -364,9 +206,161 @@ sub _christen {
 
 __PACKAGE__->meta->make_immutable;
 
-=head1 AUTHOR
 
-Robert Krimen, C<< <rkrimen at cpan.org> >>
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Google::AJAX::Library - Access the Google AJAX Libaries API in Perl
+
+=head1 VERSION
+
+version 0.021
+
+=head1 SYNOPSIS
+
+    use Google::AJAX::Library;
+
+    my $library = Google::AJAX::Library->jquery;
+
+    $library->uri
+    # http://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js
+
+    $library->html
+    # <script src="http://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js" type="text/javascript"></script>
+
+You can also fetch or write-out the library content:
+
+    my $library = Google::AJAX::Library->new(name => "mootools", version => "1.8.1");
+
+    my $content = $library->fetch;
+
+    # Into a scalar:
+    my $content;
+    $library->fetch(\$content)
+
+    # To a filehandle:
+    $library->write(\*STDOUT)
+
+    # To a file:
+    $library->write("/path/to/library.js")
+
+    # Check if a library exists at http://ajax.googleapis.com
+    # This will just do a HEAD request
+    $library->exists
+
+=head1 DESCRIPTION
+
+Google::AJAX::Library is a module for accessing the Google AJAX Libaries API via Perl
+
+You can find out more about the API here: http://code.google.com/apis/ajaxlibs/
+
+=head1 METHODS
+
+=head2 Google::AJAX::Library->jquery([ <version>, <extra> ])
+
+=head2 Google::AJAX::Library->jQuery([ <version>, <extra> ])
+
+Returns a jQuery library object of the given version
+
+If no version is given or the given version is 0, then the latest version (1) will be used
+
+You can pass through "uncompressed = 1" to get the non-compacted .js
+
+For example:
+
+    my $library = Google::AJAX::Library->jQuery(1.2, uncompressed => 1)
+
+=head2 Google::AJAX::Library->prototype([ <version> ])
+
+Returns a prototype library object of the given version
+
+If no version is given or the given version is 0, then the latest version (1) will be used
+
+A compressed .js is not offered at this time
+
+=head2 Google::AJAX::Library->scriptaculous([ <version> ])
+
+Returns a script.aculo.us library object of the given version
+
+If no version is given or the given version is 0, then the latest version (1) will be used
+
+A compressed .js is not offered at this time
+
+=head2 Google::AJAX::Library->mootools([ <version>, <extra> ])
+
+=head2 Google::AJAX::Library->MooTools([ <version>, <extra> ])
+
+Returns a MooTools library object of the given version
+
+If no version is given or the given version is 0, then the latest version (1) will be used
+
+You can pass through "uncompressed = 1" to get the non-compacted .js
+
+=head2 Google::AJAX::Library->dojo([ <version>, <extra> ])
+
+Returns a Dojo library object of the given version
+
+If no version is given or the given version is 0, then the latest version (1) will be used
+
+You can pass through "uncompressed = 1" to get the non-compacted .js
+
+=head2 $library->uri
+
+Returns the L<URI> for $library
+
+=head2 $library->version
+
+Returns the version of $library
+
+=head2 $library->name
+
+Returns the name of $library (e.g. jquery, scriptaculous, etc.)
+
+=head2 $library->file
+
+Returns the filename of $library (e.g. jquery.min.js, dojo/dojo.xd.js, etc.)
+
+=head2 $library->html
+
+Returns a properly formatted HTML <script></script> entry for $library
+
+=head2 $library->exists
+
+Returns 1 if the $library (at the URI, including the specified version) exists at http://ajax.googleapis.com/
+
+Returns 0 otherwise
+
+This method uses a HEAD request to do the checking
+
+=head2 $library->request
+
+Returns the L<HTTP::Response> of the GET request for $library
+
+=head2 $library->fetch([ <to> ])
+
+Attempts to GET $library
+
+Returns the L<HTTP::Response> decoded content If <to> is not given
+
+If <to> is a SCALAR reference then the content will be put into <to>
+
+This method is synonymous/interchangeable with C<write>
+
+=head2 $library->write( <to> )
+
+Attempts to GET $library
+
+If <to> is a GLOB reference then the content will be printed to <to>
+
+If <to> is a filename (or Path::Class::File object) then the content will be printed to the filename specified
+
+This method will croak if $library couldn't be gotten from Google (e.g. 404)
+
+This method is synonymous/interchangeable with C<fetch>
 
 =head1 SEE ALSO
 
@@ -376,56 +370,16 @@ L<JS::jQuery::Loader>
 
 L<JS::YUI::Loader>
 
-=head1 BUGS
+=head1 AUTHOR
 
-Please report any bugs or feature requests to C<bug-google-ajax-library at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Google-AJAX-Library>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+  Robert Krimen <robertkrimen@gmail.com>
 
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2010 by Robert Krimen.
 
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Google::AJAX::Library
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Google-AJAX-Library>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Google-AJAX-Library>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Google-AJAX-Library>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Google-AJAX-Library>
-
-=back
-
-
-=head1 ACKNOWLEDGEMENTS
-
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Robert Krimen
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1; # End of Google::AJAX::Library
